@@ -38,3 +38,22 @@ checking <- function() {
 testing <- function() {
   identical(Sys.getenv("TESTTHAT"), "true")
 }
+
+devel <- function() {
+  identical(R.version[["status"]], "Under development (unstable)")
+}
+
+devmode <- function() {
+
+  if ("devtools" %in% loadedNamespaces()) {
+    if (.packageName %in% devtools::dev_packages()) {
+      return(TRUE)
+    }
+  }
+
+  if (Sys.getenv("DEVTOOLS_LOAD") == .packageName)
+    return(TRUE)
+
+  FALSE
+
+}
