@@ -11,6 +11,21 @@ sprintf <- function(fmt, ...) {
   ansify(message)
 }
 
+substring <- function(text, first, last = .Machine$integer.max) {
+
+  if (!is.character(text))
+    text <- as.character(text)
+
+  n <- length(text)
+  if (n == 0L)
+    return(text)
+
+  m <- max(n, length(first), length(last))
+  text <- rep_len(text, length.out = m)
+  substr(text, first, last)
+
+}
+
 unique <- function(x) {
   base::unique(x)
 }
